﻿using Foundation;
using Syncfusion.SfSchedule.iOS;
using System;
using System.Collections.ObjectModel;
using UIKit;

namespace SyncFusionTest
{
    public partial class ViewController : UIViewController
    {
        ObservableCollection<Appointment> Items = new ObservableCollection<Appointment>();
        MonthSchedule schedule;

        public ViewController(IntPtr handle) : base(handle)
        {
        }

        public override void ViewDidLoad()
        {
            base.ViewDidLoad();

            schedule = new MonthSchedule();
            schedule.ItemsSource = Items;
            schedule.AppointmentMapping = GetAppointmentMapping();

            View.AddSubview(schedule);
        }

        public override void ViewWillAppear(bool animated)
        {
            base.ViewWillAppear(animated);

            var app1 = new Appointment
            {
                Subject = new NSString("app1"),
                Color = UIColor.Magenta,
                Start = (NSDate)(new DateTime(2019, 11, 12, 08, 00, 00, DateTimeKind.Local)),
                End = (NSDate)(new DateTime(2019, 11, 12, 09, 00, 00, DateTimeKind.Local)),
            };

            var app2 = new Appointment
            {
                Subject = new NSString("app2"),
                Color = UIColor.Magenta,
                Start = (NSDate)(new DateTime(2019, 11, 12, 06, 00, 00, DateTimeKind.Local)),
                End = (NSDate)(new DateTime(2019, 11, 12, 07, 00, 00, DateTimeKind.Local)),
            };

            Items.Add(app1);
            Items.Add(app2);

        }

        public override void DidReceiveMemoryWarning()
        {
            base.DidReceiveMemoryWarning();
            // Release any cached data, images, etc that aren't in use.
        }

        public class Appointment
        {
            public int CalendarId { get; set; }
            public bool AllDay { get; set; }
            public NSString Id { get; set; }
            public NSString Subject { get; set; }
            public NSDate Start { get; set; }
            public NSDate End { get; set; }
            public UIColor Color { get; set; }
        }

        public static AppointmentMapping GetAppointmentMapping()
        {
            AppointmentMapping mapping = new AppointmentMapping
            {
                Subject = "Subject",
                StartTime = "Start",
                EndTime = "End",
                AppointmentBackground = "Color",
                Notes = "Id",
                IsAllDay = "AllDay"
            };
            return mapping;
        }
    }

    class MonthSchedule : SFSchedule
    {
        public MonthSchedule()
        {
            TranslatesAutoresizingMaskIntoConstraints = false;

            FirstDayOfWeek = 2;
            ScheduleView = SFScheduleView.SFScheduleViewMonth;
            EnableNavigation = true;

            MonthViewSettings = new MonthViewSettings
            {
                ShowAgendaView = true,
                ShowAppointmentsInline = false,
                AgendaViewStyle = new AgendaViewStyle
                {
                    HeaderHeight = 50f
                }
            };
        }
    }
}